@@ -20,6 +20,7 @@
 #       MA 02110-1301, USA.
 
 import os, cgi, base64, shutil, copy
+import pango
 import cons, support
 
 
@@ -266,6 +267,8 @@ class Export2Pango:
             if not curr_iter.forward_char() or (sel_range and curr_iter.get_offset() > sel_range[1]):
                 if span_opened: pango_text += "</span>"
                 break
+        if len(pango_text) == 0 or pango_text[-1] != cons.CHAR_NEWLINE:
+            pango_text += cons.CHAR_NEWLINE
         return pango_text
 
     def pango_get_from_treestore_node(self, node_iter, sel_range=None):
@@ -383,7 +386,8 @@ class Export2Html:
         self.tree_links_nums = ["1"]
         for image_stock_id in cons.NODES_STOCKS:
             shutil.copy(cons.GLADE_PATH + image_stock_id + ".png", self.images_dir)
-        self.tree_links_text = '<table style="text-align:left">'
+        pango_font = pango.FontDescription(self.dad.tree_font)
+        self.tree_links_text = '<table style="text-align:left; font-family: %s; font-size:%spt">' % (pango_font.get_family(), pango_font.get_size()/pango.SCALE)
         if not top_tree_iter: tree_iter = self.dad.treestore.get_iter_first()
         else: tree_iter = top_tree_iter.copy()
         while tree_iter:
@@ -446,9 +450,11 @@ class Export2Html:
         html_text = cons.HTML_HEADER % self.dad.treestore[tree_iter][1]
         if self.tree_links_text:
             html_text += r'<table width="100%"><tr>'
-            td_tree = r'<td valign="top" align="left" width=30%>'
-            td_page = r'<td valign="top" align="left" width=70%>'
+            td_tree = r'<td valign="top" align="left" width=20%>'
+            td_page = r'<td valign="top" align="left" width=80%>'
             html_text += td_tree + self.tree_links_text + td_page
+        pango_font = pango.FontDescription(self.dad.text_font if self.dad.treestore[tree_iter][4] == cons.CUSTOM_COLORS_ID else self.dad.code_font)
+        html_text += '<span style="font-family: %s; font-size:%spt">' % (pango_font.get_family(), pango_font.get_size()/pango.SCALE)
         self.dad.get_textbuffer_from_tree_iter(tree_iter)
         if self.dad.treestore[tree_iter][4] == cons.CUSTOM_COLORS_ID:
             text_n_objects = self.html_get_from_treestore_node(tree_iter, sel_range)
@@ -461,6 +467,7 @@ class Export2Html:
                     elif curr_object[0] == "table": html_text += self.get_table_html(curr_object[1])
                     elif curr_object[0] == "codebox": html_text += self.get_codebox_html(curr_object[1])
         else: html_text += self.html_get_from_code_buffer(self.dad.treestore[tree_iter][2], sel_range)
+        html_text += "</span>"
         if self.tree_links_text:
             html_text += '</td></tr></table>'
         html_text += cons.HTML_FOOTER
@@ -521,8 +528,9 @@ class Export2Html:
     def get_codebox_html(self, codebox):
         """Returns the HTML CodeBox"""
         # codebox is: [offset, dict, justification]
+        pango_font = pango.FontDescription(self.dad.code_font)
         codebox_align_text = self.get_object_alignment_string(codebox[2])
-        codebox_html = '<table border="1" style="%s"><tr><td>' % codebox_align_text
+        codebox_html = '<table border="1" style="%s; font-family: %s; font-size:%spt"><tr><td>' % (codebox_align_text, pango_font.get_family(), pango_font.get_size()/pango.SCALE)
         codebox_html += codebox[1]['fill_text']
         codebox_html += "</td></tr></table>"
         return codebox_html
@@ -676,14 +684,18 @@ class Export2Html:
         superscript_active = False
         subscript_active = False
         monospace_active = False
+        bold_active = False
+        italic_active = False
         for tag_property in cons.TAG_PROPERTIES:
             if self.curr_attributes[tag_property] != '':
                 property_value = self.curr_attributes[tag_property]
                 #print property_value
                 if tag_property == "weight":
                     # font-weight:bolder
-                    tag_property = "font-weight"
-                    property_value = "bolder"
+                    #tag_property = "font-weight"
+                    #property_value = "bolder"
+                    bold_active = True
+                    continue
                 elif tag_property == "foreground":
                     # color:#FFFF00
                     tag_property = "color"
@@ -694,8 +706,10 @@ class Export2Html:
                     property_value = "#" + self.rgb_to_24(property_value[1:])
                 elif tag_property == "style":
                     # font-style:italic
-                    tag_property = "font-style"
-                    property_value = "italic"
+                    #tag_property = "font-style"
+                    #property_value = "italic"
+                    italic_active = True
+                    continue
                 elif tag_property == "underline":
                     # text-decoration:underline
                     tag_property = "text-decoration"
@@ -743,21 +757,12 @@ class Export2Html:
                     return
                 html_attrs += "%s:%s;" % (tag_property, property_value)
         if html_attrs == "" or inner_text == "<br/>": tagged_text = inner_text
-        else:
-            if "xx-large" in html_attrs:
-                html_attrs = html_attrs.replace("font-size:xx-large;", "")
-                tagged_text = '<h1 style="' + html_attrs + '">' + inner_text + "</h1>"
-            elif "x-large" in html_attrs:
-                html_attrs = html_attrs.replace("font-size:x-large;", "")
-                tagged_text = '<h2 style="' + html_attrs + '">' + inner_text + "</h2>"
-            elif "large" in html_attrs:
-                html_attrs = html_attrs.replace("font-size:large;", "")
-                tagged_text = '<h3 style="' + html_attrs + '">' + inner_text + "</h3>"
-            #elif "text-align" in html_attrs: self.curr_html_text += '<p style="' + html_attrs + '">' + inner_text + "</p>"
-            else: tagged_text = '<span style="' + html_attrs + '">' + inner_text + "</span>"
+        else: tagged_text = '<span style="' + html_attrs + '">' + inner_text + "</span>"
         if superscript_active: tagged_text = "<sup>" + tagged_text + "</sup>"
         if subscript_active: tagged_text = "<sub>" + tagged_text + "</sub>"
         if monospace_active: tagged_text = "<tt>" + tagged_text + "</tt>"
+        if bold_active: tagged_text = "<b>" + tagged_text + "</b>"
+        if italic_active: tagged_text = "<i>" + tagged_text + "</i>"
         self.curr_html_text += tagged_text
         #print "###############"
         #print self.curr_html_text
