@@ -35,15 +35,14 @@ class FindReplace:
         self.curr_find = [None, ""] # [latest find type, latest find pattern]
         self.from_find_iterated = False
         self.from_find_back = False
+        self.newline_trick = False
     
     def iterated_find_dialog(self):
         """Iterated Find/Replace Dialog"""
         dialog = self.dad.glade.iteratedfinddialog
         def on_key_press_iterated_find_dialog(widget, event):
             if gtk.gdk.keyval_name(event.keyval) == "Return":
-                button_box = dialog.get_action_area()
-                buttons = button_box.get_children()
-                buttons[2].clicked()
+                dialog.get_widget_for_response(1).clicked()
                 return True
         dialog.connect("key_press_event", on_key_press_iterated_find_dialog)
         response = dialog.run()
@@ -94,6 +93,11 @@ class FindReplace:
         first_fromsel = self.dad.glade.search_first_fromsel_radiobutton.get_active()
         all_matches = self.dad.glade.search_all_radiobutton.get_active()
         self.matches_num = 0
+        # searching start
+        if self.dad.user_active:
+            self.dad.user_active = False
+            user_active_restore = True
+        else: user_active_restore = False
         if all_matches:
             self.liststore_create_or_clean()
             self.all_matches_first_in_node = True
@@ -109,6 +113,7 @@ class FindReplace:
             self.dad.glade.allmatchesdialog.hide()
         elif self.dad.glade.checkbutton_iterated_find_dialog.get_active():
             self.iterated_find_dialog()
+        if user_active_restore: self.dad.user_active = True
 
     def find_in_all_nodes(self):
         """Search for a pattern in all the Tree Nodes"""
@@ -274,10 +279,6 @@ class FindReplace:
         else: pattern = re.compile(pattern, re.IGNORECASE|re.UNICODE|re.MULTILINE)
         start_offset = start_iter.get_offset()
         start_offset -= self.get_num_objs_before_offset(start_offset)
-        if start_offset == 0:
-            text = cons.CHAR_SPACE + text
-            workaround_first_empty_char = True
-        else: workaround_first_empty_char = False
         if forward:
             match = pattern.search(text, start_offset)
         else:
@@ -289,7 +290,7 @@ class FindReplace:
                                                                            start_iter.get_offset(),
                                                                            match.start(),
                                                                            forward)
-            if obj_match_offsets[0]: match_offsets = (obj_match_offsets[0], obj_match_offsets[1])
+            if obj_match_offsets[0] != None: match_offsets = (obj_match_offsets[0], obj_match_offsets[1])
             else: match_offsets = (match.start(), match.end())
         else:
             if self.replace_active: obj_match_offsets = (None, None)
@@ -297,23 +298,29 @@ class FindReplace:
                                                                            start_iter.get_offset(),
                                                                            -1,
                                                                            forward)
-            if obj_match_offsets[0]: match_offsets = (obj_match_offsets[0], obj_match_offsets[1])
+            if obj_match_offsets[0] != None: match_offsets = (obj_match_offsets[0], obj_match_offsets[1])
             else: match_offsets = (None, None)
-        if match_offsets[0]:
-            if workaround_first_empty_char: match_offsets = (match_offsets[0]-1, match_offsets[1]-1)
-            if not obj_match_offsets[0]: num_objs = self.get_num_objs_before_offset(match_offsets[0])
+        if match_offsets[0] != None:
+            if obj_match_offsets[0] == None: num_objs = self.get_num_objs_before_offset(match_offsets[0])
             else: num_objs = 0
-            self.dad.set_selection_at_offset_n_delta(match_offsets[0] + num_objs,
-                                                     match_offsets[1] - match_offsets[0])
+            final_start_offset = match_offsets[0] + num_objs
+            final_delta_offset = match_offsets[1] - match_offsets[0]
+            #print "IN", final_start_offset, final_delta_offset, self.dad.treestore[self.dad.curr_tree_iter][1]
+            #for count in range(final_delta_offset):
+            #    print count, self.dad.curr_buffer.get_iter_at_offset(final_start_offset+count).get_char()
+            self.dad.set_selection_at_offset_n_delta(final_start_offset, final_delta_offset)
+            #print "OUT"
             mark_insert = self.dad.curr_buffer.get_insert()
             iter_insert = self.dad.curr_buffer.get_iter_at_mark(mark_insert)
             self.dad.sourceview.scroll_to_mark(mark_insert, 0.25)
             if all_matches:
+                if self.newline_trick: newline_trick_offset = 1
+                else: newline_trick_offset = 0
                 self.liststore.append([self.dad.curr_tree_iter,
-                                       match_offsets[0] + num_objs,
-                                       match_offsets[1] + num_objs,
+                                       match_offsets[0] + num_objs - newline_trick_offset,
+                                       match_offsets[1] + num_objs - newline_trick_offset,
                                        self.dad.treestore[self.dad.curr_tree_iter][1],
-                                       self.get_line_content(iter_insert) if not obj_match_offsets[0] else obj_match_offsets[2]])
+                                       self.get_line_content(iter_insert) if obj_match_offsets[0] == None else obj_match_offsets[2]])
             if self.replace_active:
                 replacer_text = self.dad.glade.replace_entry.get_text().decode("utf-8")
                 self.dad.curr_buffer.delete_selection(interactive=False, default_editable=True)
@@ -322,9 +329,9 @@ class FindReplace:
                     self.dad.set_selection_at_offset_n_delta(match_offsets[0] + num_objs,
                                                              len(replacer_text))
                 self.dad.state_machine.update_state(self.dad.treestore[self.dad.curr_tree_iter][3])
-                self.dad.ctdb_handler.pending_edit_db_node_buff(self.dad.treestore[self.dad.curr_tree_iter][3])
+                self.dad.ctdb_handler.pending_edit_db_node_buff(self.dad.treestore[self.dad.curr_tree_iter][3], force_user_active=True)
             return True
-        else: return False
+        return False
     
     def check_pattern_in_object(self, pattern, obj):
         """Search for the pattern in the given object"""
@@ -372,6 +379,15 @@ class FindReplace:
 
     def parse_current_node_content(self, pattern, forward, first_fromsel, all_matches, first_node):
         """Returns True if pattern was find, False otherwise"""
+        buff_start_iter = self.dad.curr_buffer.get_start_iter()
+        if buff_start_iter.get_char() != cons.CHAR_NEWLINE:
+            self.newline_trick = True
+            if not self.dad.curr_buffer.get_modified(): restore_modified = True
+            else: restore_modified = False
+            self.dad.curr_buffer.insert(buff_start_iter, cons.CHAR_NEWLINE)
+        else:
+            self.newline_trick = False
+            restore_modified = False
         if (first_fromsel and first_node)\
         or (all_matches and not self.all_matches_first_in_node):
             iter_insert = self.dad.curr_buffer.get_iter_at_mark(self.dad.curr_buffer.get_insert())
@@ -396,7 +412,15 @@ class FindReplace:
             if forward: start_iter = self.dad.curr_buffer.get_start_iter()
             else: start_iter = self.dad.curr_buffer.get_end_iter()
             if all_matches: self.all_matches_first_in_node = False
-        return self.find_pattern(pattern, start_iter, forward, all_matches)
+        pattern_found = self.find_pattern(pattern, start_iter, forward, all_matches)
+        if self.newline_trick:
+            buff_start_iter = self.dad.curr_buffer.get_start_iter()
+            buff_step_iter = buff_start_iter.copy()
+            if buff_step_iter.forward_char(): self.dad.curr_buffer.delete(buff_start_iter, buff_step_iter)
+            if restore_modified: self.dad.curr_buffer.set_modified(False)
+        if self.replace_active and pattern_found:
+            self.dad.update_window_save_needed("nbuf")
+        return pattern_found
 
     def parse_given_node_content(self, node_iter, pattern, forward, first_fromsel, all_matches):
         """Returns True if pattern was found, False otherwise"""
